{% extends "statusboard/base.html" %}

{% load statusboard_extras %}
{% load i18n %}

{% block content %}
<div class="container">
    <div class="page-header">
        <h1>%{ trans "Delete a service" %}</h1>
    </div>
    <form class="form-horizontal" role="form" method="post" action="">
        {% csrf_token %}
        <p class="col-sm-10">{% blocktrans %}Are you sure you want to delete the service "{{ service }}"?{% endblocktrans %}</p>
        <div class="form-group">
            <div class="col-sm-2">
                <input type="submit" class="btn btn-primary" value="{% trans "Confirm" %}">
            </div>
        </div>
    </form>
</div>
{% endblock %}

