# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-01-21 20:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0002_incident'),
    ]

    operations = [
        migrations.AlterField(
            model_name='service',
            name='groups',
            field=models.ManyToManyField(related_name='services', related_query_name='service', to='statusboard.ServiceGroup'),
        ),
    ]
