# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-02-01 10:17
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('statusboard', '0003_auto_20170121_2030'),
        ('statusboard', '0004_incident_occurred'),
    ]

    operations = [
    ]
