{% extends "statusboard/base.html" %}

{% load statusboard_extras %}
{% load i18n %}

{% block content %}
<div class="container">
    <div class="page-header">
        <h1>{% trans "Edit service group" %}</h1>
    </div>
    {% include "statusboard/servicegroup/form.html" %}
</div>
{% endblock %}

